
' SEAV FONT II (1997)
' 
'
'                                    Copyright (C) 1997, SEAV Softwares
'
'                                    This program written by Eugene Villar
'                                    a.k.a SEAV (evillar@geocities.com).
'
'                                    Visit my web site at
'                                    http://seav.findhere.com
'
' 
'
' This is a useful font program containing subs and functions that utilize
' a font I created which is saved in a file (FONTSV2.002).
'
' The font can be used in any graphics screen mode but is easily read in
' 320x200 (Screen 1,7,13), 640x200 (Screen 2,8), or 640x350 (Screen 9,10).
'
' Font description:                                      SAMPLE
'        TYPE  proportional bit-map font                            
'        SIZE  Maximum height: 11 pixels                 
'                Body: 5 pixels                         
'                Ascending: 2 pixels                  
'                Drop: 2 pixels                                  
'    TYPEFACE  sans serif                                              
'  CHARACTERS  uppercase and lowercase letters, 0-9 numerals, all punctuation
'              marks that can be entered by keyboard, 2 quotation marks ASCII
'              34 and 31, degree sign () ASCII 248, and squared sign ()
'              ASCII 253.
'  ADDITIONAL  numerals are monospaced at width 6 pixels with 1 pixel space
'              for a total width of 7 pixels.
'
' Please credit me when you use any of my font routines in your program:
' "Fonts by: Eugene Villar" or such.
'
' Following are explanations on all the routines and instructions on how to
' use them and a demo program.
'
'
' SUB: SAVE.FONTS
' ---------------------------------------------------------------------------
' This sub saves the font into a data file (FONTSV2.002). You don't need to
' call this subroutine since the file was already created.
'
'                                     
' SUB: LOAD.FONTS
' ---------------------------------------------------------------------------
' This sub loads the font into arrays from a file (FONTSV2.002). The font can
' then be used by other functions and subs provided by this program.
'
' SYNTAX:  LOAD.FONTS
'
' NOTES: Before loading the fonts, include a statement or two in the main
'    module (the main program) that declares the two arrays the font routines
'    need. The arrays need to be global so include the SHARED keyword too.
'
'    DIM SHARED FONT$(0 TO 255)
'    DIM SHARED FONSZ(0 TO 255)
'
'                                     
' FUNCTION: FONT.CONV$
' ---------------------------------------------------------------------------
' This function returns the SEAV Font #2 DRAW Commandstring version of a
' specified text.
'
' SYNTAX:  FONT.CONV$(stringexpression$)
'
'       stringexpression$     - the text you want to convert to the font
'                                style.
'
' EXAMPLE:     SCREEN 13
'              D$ = FONT.CONV$("SEAV Font II")
'              DRAW "bm50,90x" + VARPTR$(D$)
'
' NOTES: The function can set the color of the succeeding text by placing an
'    ASCII character 30 plus the ASCII character with code no. equal to the
'    color no. w/in the text. Example:
'
'    CHR$(30) + CHR$(15) + "Hello! " + CHR$(13) + CHR$(30) + CHR$(14) + "Hi!"
'
'    The function will convert this example to a DRAW string where "Hello! "
'    is in color 30 followed by "Hi!" in color 14.
'
'    To be able to use the converted text, you must use a DRAW statement
'    with the "X" + VARPTR$(commandstring$) arguments.
'
'                                     
' SUB: PUT.TEXT
' ---------------------------------------------------------------------------
' Takes a piece of text then writes it in paragraph style using SEAV Font #2
' on a specified location on the screen.
'
' SYNTAX:  PUT.TEXT(stringexpression$, xs%, ys%, xm%)
'
'       stringexpression$     - the text you want to write to the screen.
'       xs%                   - X-coordinate where writing starts
'       ys%                   - Y-coordinate where writing starts
'       xm%                   - maximum X-coordinate of writing
'
' EXAMPLE:    SCREEN 7
'             TXT$ = "This subroutine can be used to write whole paragraphs "
'             TXT$ = TXT$ +"of text and cuts words at spaces or at hyphens. "
'             TXT$ = TXT$ +"Additionally, you can put ASCII Character 13 in "
'             TXT$ = TXT$ +"the text to cut the text manually. "
'             PUT.TEXT TXT$, 1, 1, 319
'
' NOTES: The subroutine writes the text in paragraph style, wrapping the text
'    to the next line when the maximum X-coordinate specified is reached. It
'    cuts the text at spaces, hyphens, and imbedded ASCII character 13's
'    (return character).
'
'    The sub also sets color. See Notes on FONT.CONV$ for an explanation on
'    how to do this.
'
'    Please note that errors may occur if some words do not fit in the space
'    provided (XSTART to XMAX). To remedy, use hyphens.
'
'                                     
' FUNCTION: INPUT.TEXT$
' ---------------------------------------------------------------------------
' Lets user enter a piece of text, echoing his input on the screen at a
' specified location and returning various values based on input.
'
' SYNTAX:
'     INPUT.TEXT$(stringexpression$, xs%, ys%, xm%, foreground%, background%)
'
'       stringexpression$     - initial input text (used in default input)
'       xs%                   - X-coordinate where echoing of input starts
'       ys%                   - Y-coordinate where echoing of input starts
'       xm%                   - maximum X-coordinate of echoing. Also
'                                provides for limitation for input length:
'                                can't input anymore if the text exceeds this
'                                value.
'       foreground%           - color of the text and cursor
'       background%           - background color of input field
'
' EXAMPLE:    SCREEN 7
'             PUT.TEXT "Enter directory to display:", 1, 1, 319
'             PATH$ = INPUT.TEXT$("C:\WINDOWS\", 1, 15, 319, 15, 8)
'
' NOTES: The input terminates when the user presses ENTER, TAB, or ESC. The
'    values returned are:
'
'    ENTER: input string
'      TAB: CHR$(9)  <--TAB character
'      ESC: CHR$(27) <--ESC character
'
'    If you're going to use this function, please include the COL$ function
'    too. See next item for details on COL$.
'
'                                     
' FUNCTION: COL$
' ---------------------------------------------------------------------------
' If you want to add color to your text but would hate to type CHR$(30) +
' CHR$(color value), then this function is for you! This function returns the
' color command (i.e., CHR$(30) + CHR$(color value)) given the color value.
'
' SYNTAX:  COL$(colorvalue%)
'
'       colorvalue%           - the color attribute. A value in the range
'                                0 to 255.
'
' EXAMPLE:    SCREEN 7
'             PUT.TEXT COL$(15) + "Color 15 " + COL$(4) + "Color 4", 1, 1, 319
'
'                                     
'
'----------------------------- start of program -----------------------------

'declare various font routines
DECLARE FUNCTION COL$ (COLOR1%)
DECLARE FUNCTION FONT.CONV$ (TXT$)
DECLARE FUNCTION INPUT.TEXT$ (TXT$, XSTART%, YSTART%, XMAX%, FORE%, BACK%)
DECLARE SUB PUT.TEXT (TXT$, XSTART%, YSTART%, XMAX%)
DECLARE SUB LOAD.FONTS ()
DECLARE SUB SAVE.FONTS ()

'declare demo routines
DECLARE SUB demo1 ()
DECLARE SUB demo2 ()

'define all undefined variables as INTEGER for fast execution
DEFINT A-Z

'declare required font arrays
DIM SHARED FONT$(255)
DIM SHARED FONSZ(255)

'load the fonts in the arrays
LOAD.FONTS

'SAVE.FONTS

'start demo
'main loop
DO
   'set screen
   SCREEN 0
   WIDTH 80
   CLS

   'print menu
   PRINT "SEAV Font #2 Demo"
   PRINT "-----------------"
   PRINT
   PRINT "1. PUT.TEXT subroutine demo"
   PRINT "2. INPUT.TEXT$ function demo"
   PRINT "3. Exit"
   PRINT
   PRINT "Press the key of your choice"

   'wait for keypress
   DO
      IN$ = INPUT$(1)
   LOOP UNTIL IN$ > "0" AND IN$ < "4"
  
   'branch to demos
   SELECT CASE VAL(IN$)
      CASE 1: demo1
      CASE 2: demo2
   END SELECT
LOOP UNTIL IN$ = "3"

END 'font2.bas

FUNCTION COL$ (COLOR1)
   IF COLOR1 < 256 AND COLOR1 > -1 THEN
      COL$ = CHR$(30) + CHR$(COLOR1)
   END IF
END FUNCTION

SUB demo1

   SCREEN 13
  
   'draw background
   FOR I = 0 TO 15
      PALETTE I + 16, I * 2 + 15 + (65792) * 10
      PALETTE I + 48, I * 2 + 30 + (65792) * 20
   NEXT
   DEF SEG = &HA000
   BLOAD "SEAVBG02.GFX", 0
   DEF SEG
   DIM TT(2000)
   GET (1, 1)-(318, 12), TT
   LINE (1, 1)-(318, 12), 32, BF
   PUT (1, 1), TT, OR

   TXT$ = COL$(14) + "SEAV Font 2" + CHR$(13) + CHR$(13) + COL$(15)
   TXT$ = TXT$ + "     This is a useful font program containing subs and functions that utilize "
   TXT$ = TXT$ + "a font I created which is saved in a file " + COL(11) + "(FONTSV2.002)" + COL$(15) + "." + CHR$(13)
   TXT$ = TXT$ + "     The font can be used in any graphics screen mode but is easily read in "
   TXT$ = TXT$ + COL$(13) + "320x200" + COL$(15) + " (Screen 1, 7, 13), " + COL$(13) + "640x200" + COL$(15)
   TXT$ = TXT$ + " (Screen 2, 8), or " + COL$(13) + "640x350" + COL$(15) + " (Screen 9, 10)." + CHR$(13) + CHR$(13)
   TXT$ = TXT$ + COL$(12) + "Character Set" + COL$(14) + CHR$(13)
   TXT$ = TXT$ + "     ABCDEFGHIJKLMNOPQRSTUVWXYZ" + CHR$(13)
   TXT$ = TXT$ + "     abcdefghijklmnopqrstuvwxyz" + CHR$(13)
   TXT$ = TXT$ + "     1234567890 +-=*/\^%<>" + CHR$(13)
   TXT$ = TXT$ + "     .,:;!?`'" + CHR$(34) + CHR$(31) + " ()[]{}| &$#@"

   PUT.TEXT TXT$, 3, 3, 316
  
   PUT.TEXT COL$(7) + "Press any key to go back to the menu.", 3, 183, 316
   IN$ = INPUT$(1)

END SUB

SUB demo2
  
   'display dialog box (ala Windows 95)
   SCREEN 7
   LINE (0, 0)-(319, 199), 7, BF
   LINE (0, 198)-(0, 0), 15
   LINE -(318, 0), 15
   LINE (319, 1)-(319, 199), 8
   LINE -(1, 199), 8
   LINE (2, 2)-(317, 14), 8, BF
   LINE (4, 40)-(315, 54), 15, B
   LINE (4, 54)-(4, 40), 8
   LINE -(315, 40), 8
   LINE (5, 41)-(313, 52), 7, BF
   LINE (200, 180)-(254, 194), 15, B
   LINE (201, 194)-(254, 194), 8
   LINE -(254, 180), 8
   LINE (260, 180)-(314, 194), 15, B
   LINE (261, 194)-(314, 194), 8
   LINE -(314, 180), 8
   DRAW "BM3,3 C4D10R10U10L9BDP4,4C14BR8L7GRGRDR6FLFLDL7C11BF3BRUEUERERD5L5BEP11,11"
   DRAW "BM316,3C7D10L11U10R10BDP7,7RC0D9L10HC15U9R10C8BDBGG6LE6BL6F6RH6"
   PUT.TEXT COL$(15) + "DISPLAY", 18, 5, 315
   PUT.TEXT COL$(0) + "Enter directory/folder to display:", 5, 29, 315
   PUT.TEXT COL$(0) + "OK", 222, 184, 254
   PUT.TEXT COL$(0) + "Cancel", 269, 184, 314
          
   'input
   PATH$ = INPUT.TEXT$("C:\WINDOWS\", 6, 42, 313, 0, 7)
          
   'carry command
   IF PATH$ <> CHR$(27) AND PATH$ <> CHR$(9) THEN
      SCREEN 0
      WIDTH 80
      FILES PATH$
             
      LOCATE 23
      PRINT "Press any key to go back to the menu."
      IN$ = INPUT$(1)
   END IF

END SUB

'
' This function returns the SEAV Font #2 DRAW Commandstring version of the
' specified text, TXT$. Can set the color of the succeeding text by placing
' an ASCII character #30 plus the ASCII code no. equal to the color no. w/in
' the text. Example:
'
' CHR$(30) + CHR$(15) + "Hello! " + CHR$(30) + CHR$(14) + "Hi!"
'
' The function will convert this example to a DRAW string where "Hello! "
' is in color 30 followed by "Hi!" in color 14.
'
FUNCTION FONT.CONV$ (TXT$)

   IF TXT$ <> "" THEN
      FOR I = 1 TO LEN(TXT$)
         T$ = MID$(TXT$, I, 1)
         IF FONSZ(ASC(T$)) > 0 THEN
            D$ = D$ + FONT$(ASC(T$))
         ELSE
            IF T$ = CHR$(30) THEN D$ = D$ + "C" + STR$(ASC(MID$(TXT$, I + 1, 1)))
            I = I + 1
         END IF
      NEXT
      FONT.CONV$ = D$
   END IF

END FUNCTION

'
' An INPUT routine using SEAV Font 2.
'
'   TXT$ - initial input text
' XSTART - X-coordinate where writing starts
' YSTART - Y-coordinate where writing starts
'   XMAX - maximum X-coordinate of input
'   FORE - foreground color
'   BACK - background color
'
FUNCTION INPUT.TEXT$ (TXT$, XSTART, YSTART, XMAX, FORE, BACK)
  
   'determine position of cursor after initial input text
   XCOOR = XSTART
   FOR I = 1 TO LEN(TXT$)
      XCOOR = XCOOR + FONSZ(ASC(MID$(TXT$, I, 1)))
   NEXT
  
   'draw input field and initial input text
   LINE (XSTART, YSTART)-(XMAX, YSTART + 10), BACK, BF
   PUT.TEXT COL$(FORE) + TXT$, XSTART, YSTART + 1, XMAX
  
   'loop to input characters
   DO
      'display blinking cursor
      SELECT CASE INT(TIMER * 2&) MOD 2
         CASE 0: LINE (XCOOR + 1, YSTART)-(XCOOR + 2, YSTART + 10), FORE, BF
         CASE 1: LINE (XCOOR + 1, YSTART)-(XCOOR + 2, YSTART + 10), BACK, BF
      END SELECT
     
      'receive character
      IN$ = LEFT$(INKEY$, 1)
     
      'make decision based on character input
      IF LEN(IN$) > 0 THEN
         SELECT CASE IN$
            CASE CHR$(9)                 'user pressed TAB: input is TAB
               EX = 1: TXT$ = CHR$(9)
            CASE CHR$(27)                'user pressed ESC: input is ESC
               EX = 1: TXT$ = CHR$(27)
            CASE CHR$(13)                'user pressed ENTER
               EX = 1
            CASE CHR$(8)                 'user pressed BACKSPACE; delete char
               IF TXT$ <> "" THEN
                  CHAR$ = RIGHT$(TXT$, 1)
                  XCOOR = XCOOR - FONSZ(ASC(CHAR$))
                  LINE (XCOOR, YSTART)-(XMAX, YSTART + 10), BACK, BF
                  TXT$ = LEFT$(TXT$, LEN(TXT$) - 1)
               END IF
            CASE ELSE                   'user pressed other keys, add to input
               IF XCOOR + FONSZ(ASC(IN$)) + 1 < XMAX AND FONSZ(ASC(IN$)) > 0 THEN
                  TXT$ = TXT$ + IN$
                  LINE (XCOOR, YSTART)-(XMAX, YSTART + 10), BACK, BF
                  PUT.TEXT COL$(FORE) + TXT$, XSTART, YSTART + 1, XMAX
                  XCOOR = XCOOR + FONSZ(ASC(IN$))
               END IF
         END SELECT
      END IF
   LOOP UNTIL EX = 1
  
   'return value of input
   INPUT.TEXT$ = TXT$

END FUNCTION

'
' Loads SEAV font #2 into shared arrays.
'
' FONT$() - contains the DRAW string value for each character
' FONSZ() - contains the width of each character (which is used for spacing.)
'
SUB LOAD.FONTS
 
   OPEN "fontsv2.002" FOR INPUT AS #1     'Data file for Font #2
   TMP$ = CHR$(0)
   DO
      LINE INPUT #1, TMP$
      CHR = ASC(LEFT$(TMP$, 1))
      TMP = INSTR(2, TMP$, CHR$(255))
      FONT$(CHR) = MID$(TMP$, 2, TMP - 2)
      FONSZ(CHR) = VAL(MID$(TMP$, TMP + 1))
   LOOP UNTIL EOF(1)
   CLOSE

END SUB

'
' Takes a piece of text then writes it using SEAV Font #2 on a specified
' location on the screen.
'
'   TXT$ - the text to be written
' XSTART - X-coordinate where writing starts
' YSTART - Y-coordinate where writing starts
'   XMAX - maximum X-coordinate of input
'
SUB PUT.TEXT (TXT$, XSTART, YSTART, XMAX)
 
   'don't write if XSTART is >= XMAX
   IF XSTART >= XMAX THEN EXIT SUB
  
   XCOOR = XSTART
   TXT1 = 1
   TXT2 = 1
   LINES = 0

   TXT$ = TXT$ + " "

   FOR I = 1 TO LEN(TXT$)
      WRITE$ = ""
      CHAR$ = MID$(TXT$, I, 1)
      XCOOR = XCOOR + FONSZ(ASC(CHAR$))
      IF CHAR$ = " " OR CHAR$ = "-" OR CHAR$ = CHR$(13) THEN
         IF CHAR$ = " " THEN XCOOR = XCOOR - FONSZ(32)
         IF XCOOR > XMAX OR CHAR$ = CHR$(13) THEN
            IF CHAR$ = CHR$(13) AND XCOOR <= XMAX THEN
               TXT1 = I
               WRITE$ = FONT.CONV$(MID$(TXT$, TXT2, I - TXT2))
            ELSE
               CHAR$ = MID$(TXT$, TXT1, 1)
               IF CHAR$ = " " OR CHAR$ = CHR$(13) THEN WRITE$ = FONT.CONV$(MID$(TXT$, TXT2, TXT1 - TXT2))
               IF CHAR$ = "-" THEN WRITE$ = FONT.CONV$(MID$(TXT$, TXT2, TXT1 - TXT2 + 1))
            END IF
            WRITE$ = "BM" + STR$(XSTART) + "," + STR$(LINES * 11 + YSTART) + WRITE$
            DRAW "X" + VARPTR$(WRITE$)
            TXT2 = TXT1 + 1
            I = TXT1
            LINES = LINES + 1
            XCOOR = XSTART
         ELSE
            TXT1 = I
            IF CHAR$ = " " THEN XCOOR = XCOOR + FONSZ(32)
         END IF
      ELSE
         IF CHAR$ = CHR$(30) THEN I = I + 1
      END IF
   NEXT
   WRITE$ = FONT.CONV$(MID$(TXT$, TXT2, LEN(TXT$) - TXT2 + 1))
   WRITE$ = "BM" + STR$(XSTART) + "," + STR$(LINES * 11 + YSTART) + WRITE$
   DRAW "X" + VARPTR$(WRITE$)

END SUB

'
' Contains the font data which is saved into a file.
'
SUB SAVE.FONTS
  
   '--- char DRAW commands ---
   FONT$(31) = "du2fubr2d2eubrbf"                   ' back quotes
   FONT$(32) = "br5"                                ' space
   FONT$(33) = "d4bd2rbu2u4br2"                     '!
   FONT$(34) = "dru2brbfdru2brbf"                   '"
   FONT$(35) = "bd2nr6bd2nr6rdu4rd4br2u4rd4be3bu2"  '#
   FONT$(36) = "br3bud8h2lfr4elelul4hrhrur4drbebr"  '$
   FONT$(37) = "bd2rbf4lbl4ne4re4be2"               '%
   FONT$(38) = "bffuurrddegl2dgldfnr2u3rf3rhu2rglhbe3br2"   '&
   FONT$(39) = "du2fubrbf"                          ''
   FONT$(40) = "d8frlu10rbr1bf"                     '(
   FONT$(41) = "burd10lreu8br2"                     ')
   FONT$(42) = "bfrddnl2ddlrefrhunr2ulnderbebr2"    '*
   FONT$(43) = "bd3r2nd2nu2rnd2nr2u2br4bu"          '+
   FONT$(44) = "brbd5dgreube2bu3"                   ',
   FONT$(45) = "bd3r5be2bu"                         '- (minus sign)
   FONT$(46) = "bd5drube2bu3"                       '.
   FONT$(47) = "bd7u2fdu5fdu5fdu2br2bd"             '/
   FONT$(48) = "bdd4fnr2u6r3d6eu4bebr"              '0
   FONT$(49) = "bfed6ru6br4"                        '1
   FONT$(50) = "bd6nr5ururur2euhnd2l3dlbr6be"       '2
   FONT$(51) = "bd5rdr3elelunl2elelul3dlbr6be"      '3
   FONT$(52) = "bd4nr4ue3rnd6ng4rnd6br2"            '4
   FONT$(53) = "bd5rdr3elelul4u3rnd3r4br2"          '5
   FONT$(54) = "bdd4fr3elelul3nd2u3r3drbebr"        '6
   FONT$(55) = "r4d2g2d2ru2e2u2br2"                 '7
   FONT$(56) = "bdrgrdnr3grgrdr3eleluelelunl3br3"   '8
   FONT$(57) = "bd5rdr3elelul3hrhrur3d2fu2bebr"     '9
   FONT$(58) = "bd2dbd2drubu2ube2"                  ':
   FONT$(59) = "bfbddbd2dgreubu2ube2"               ';
   FONT$(60) = "br3g3f3rh3e3br2"                    '<
   FONT$(61) = "bd2nr4bd2r4be2bu2"                  '=
   FONT$(62) = "f3g3re3h3br5"                       '>
   FONT$(63) = "bdrur3ddg2nubd2rbu2e2ubebr"         '?
   FONT$(64) = "bf3bdlu2r2dfeu2hl4gd4fr4be3bu3"     '@
   FONT$(65) = "bd2d4ru5erfd3nl2d2ru4be2"           'A
   FONT$(66) = "d6rnu6r3elelunl2elelunl2br3"        'B
   FONT$(67) = "bdd4fr3elbl3u5r3drbebr"             'C
   FONT$(68) = "d6ru6r3d6nl2eu4bebr"                'D
   FONT$(69) = "d6rnr4u3nr2u3r4br2"                 'E
   FONT$(70) = "d6ru3nr2u3r4br2"                    'F
   FONT$(71) = "bdd4fr3u3lr2d2bl4u5r3drbebr"        'G
   FONT$(72) = "d6ru3nu3r3nu3d3ru6br2"              'H
   FONT$(73) = "d6ru6br2"                           'I
   FONT$(74) = "bd5rdr3u6rnd5br2"                   'J
   FONT$(75) = "d6ru3nu3rf2druh2ueurdng2bebr"       'K
   FONT$(76) = "d6rnr3u6br5"                        'L
   FONT$(77) = "d6ru6nf3df3e3ung3d6ru6br2"          'M
   FONT$(78) = "d6ru6nf3df4du6rnd6br2"              'N
   FONT$(79) = "bdd4fnr2u6r3d6eu4bebr"              'O
   FONT$(80) = "d6ru6r3d4nl2eu2bebr"                'P
   FONT$(81) = "bdd4fnr2u6r3d6grdrbu3u4bebr"        'Q
   FONT$(82) = "d6ru6r3d4nl2d2ruheu2bebr"           'R
   FONT$(83) = "bd5rdr3elelul3hrhrur3drbebr"        'S
   FONT$(84) = "r2d6ru6r2br2"                       'T
   FONT$(85) = "d5fnu6r3u6rnd5br2"                  'U
   FONT$(86) = "d4fnu5freu5rnd4br2"                 'V
   FONT$(87) = "d6rnu6ne3ue3f3dnh3u6rnd6br2"        'W
   FONT$(88) = "df4druh4ubd6ue4uldg4dbe6br"         'X
   FONT$(89) = "d2f2d2ru2h2u2br3d2g2re2u2br2"       'Y
   FONT$(90) = "r4dg4dnr5rue4ubr2"                  'Z
   FONT$(91) = "ud10r2lu10rbrbf"                    '[
   FONT$(92) = "ud2eud5eud5eud2be2bu5"              '\
   FONT$(93) = "burd10lr2u10brbf"                   ']
   FONT$(94) = "bdruedrdrbrbe"                      '^
   FONT$(95) = "bd8r4bu8br2"                        '_
   FONT$(96) = "budfu2brbf"                         '`
   FONT$(97) = "bd3ddfu4r3d4nl3ru4be2"              'a
   FONT$(98) = "d6r4euuhnd3l3nd3uubr6"              'b
   FONT$(99) = "bd3ddfr3elbl3u3r3drbe2bu"           'c
   FONT$(100) = "bd3ddfu4r3uurd6nl3hu5br3"          'd
   FONT$(101) = "bd3ddfnr3u4r3ddnl2rube2bu"         'e
   FONT$(102) = "bd2rnr2d4ru6gerbr2"                'f
   FONT$(103) = "bd3ddfu4r3d4nl3d2nl3eu5be2"        'g
   FONT$(104) = "d6ru4r3d4ru3hl3u2br6"              'h
   FONT$(105) = "bd2d4ru4bu2lbr3"                   'i
   FONT$(106) = "brbd2d6lreu5bu2lbr3"               'j
   FONT$(107) = "d6ru2rf2rh2e2lg2hu3br6"            'k
   FONT$(108) = "d6ru6br2"                          'l
   FONT$(109) = "bd2d4ru4r2d4ru4r2d4ru3be2bu"       'm
   FONT$(110) = "bd2d4ru4r3d4ru3be2bu"              'n
   FONT$(111) = "bd3ddfnr2u4r3d4euube2bu"           'o
   FONT$(112) = "bd2d6ru2nr2u4r3d4euube2bu"         'p
   FONT$(113) = "bd3ddfnr2u4r3d6ru6be2"             'q
   FONT$(114) = "bd2d4ru4r2flbe3"                   'r
   FONT$(115) = "bd3fnu2r2ddnl3ebh2bur2be2"         's
   FONT$(116) = "brd2nld3fnru4nru2br3"              't
   FONT$(117) = "bd2d3fnu4r3u4rnd4be2"              'u
   FONT$(118) = "bd4uurd3freu3rnd2be2"              'v
   FONT$(119) = "bd5u3rd4r2u4rd4r2u4rnd3be2"        'w
   FONT$(120) = "bd2f4rh4bd4le4rng4be2"             'x
   FONT$(121) = "bd2d3fnu4r3nu4d2nl3eu5be2"         'y
   FONT$(122) = "bd2r4g4nr5re4be2"                  'z
   FONT$(123) = "bebrgd3gfd3frhu3heu3ebrbf"         '{
   FONT$(124) = "ud8ru8dbr2"                        '|
   FONT$(125) = "bufd3fgd3greu3ehu3hbr3bf"          '}
   FONT$(126) = "bderdrebr2"                        '~
   FONT$(248) = "brgfrhefgrehbr3"                   '
   FONT$(249) = "bd3r3be2bu"                        ' hyphen
   FONT$(250) = "bd3r9be2bu"                        ' dash
   FONT$(253) = "berfg2r2be2"                       '
   FONT$(255) = "br7"                               ' numeral space
               
   '--- char sizes ---
   FONSZ(31) = 6: FONSZ(32) = 5: FONSZ(33) = 3: FONSZ(34) = 6: FONSZ(35) = 8
   FONSZ(36) = 8: FONSZ(37) = 7: FONSZ(38) = 8: FONSZ(39) = 3: FONSZ(40) = 4
   FONSZ(41) = 4: FONSZ(42) = 8: FONSZ(43) = 7: FONSZ(44) = 4: FONSZ(45) = 7
   FONSZ(46) = 3: FONSZ(47) = 5: FONSZ(48) = 7: FONSZ(49) = 7: FONSZ(50) = 7
   FONSZ(51) = 7: FONSZ(52) = 7: FONSZ(53) = 7: FONSZ(54) = 7: FONSZ(55) = 7
   FONSZ(56) = 7: FONSZ(57) = 7: FONSZ(58) = 3: FONSZ(59) = 4: FONSZ(60) = 6
   FONSZ(61) = 6: FONSZ(62) = 6: FONSZ(63) = 7: FONSZ(64) = 8
   FOR I = 65 TO 90: FONSZ(I) = 7: NEXT
   FONSZ(73) = 3: FONSZ(76) = 6: FONSZ(77) = 10: FONSZ(78) = 8: FONSZ(87) = 10
   FONSZ(91) = 4: FONSZ(92) = 5: FONSZ(93) = 4: FONSZ(94) = 6: FONSZ(95) = 6
   FONSZ(96) = 3
   FOR I = 97 TO 122: FONSZ(I) = 7: NEXT
   FONSZ(102) = 5: FONSZ(105) = 3: FONSZ(106) = 4: FONSZ(108) = 3: FONSZ(109) = 9
   FONSZ(114) = 6: FONSZ(115) = 6: FONSZ(116) = 5: FONSZ(119) = 9
   FONSZ(123) = 5: FONSZ(124) = 3: FONSZ(125) = 5: FONSZ(126) = 6
   FONSZ(248) = 6: FONSZ(249) = 5: FONSZ(250) = 11: FONSZ(253) = 4: FONSZ(255) = 7
 
   '--- Font Saver (FONTSV2.002) ---
 
   OPEN "fontsv2.002" FOR OUTPUT AS #1
   FOR I = 1 TO 255
      IF FONSZ(I) > 0 THEN
         PRINT #1, CHR$(I); FONT$(I); CHR$(255); LTRIM$(STR$(FONSZ(I)))
      END IF
   NEXT
   CLOSE

END SUB

